const db = require('../../shared/db');

async function getCategoriesToTryCheck(limit) {

    const query = `SELECT id, url, nodeId, departmentId, tryCheckedAt, checkedAt, productsCount,
CONCAT(
'TechnicalForm.SiteMapNodeId=', nodeId,
'&TechnicalForm.DepartmentId=', departmentId,
'&TechnicalForm.ProductId=&hdnPageType=ProductList&TechnicalForm.ContentTypeId=3&TechnicalForm.SellerId=&TechnicalForm.PageType=PRODUCTLISTER&TechnicalForm.LazyLoading.ProductSheets=False&TechnicalForm.BrandLicenseId=0&FacetForm.SelectedFacets%5B0%5D=Choix+de+livraison%2Fexp%C3%A9di%C3%A9+par+cdiscount&SortForm.SelectedSort=PERTINENCE&ProductListTechnicalForm.Keyword=&ProductListTechnicalForm.TemplateName=Grid'
) AS payload
FROM categories
WHERE (tryCheckedAt IS NULL OR tryCheckedAt <= DATE_SUB(NOW(), INTERVAL 5 MINUTE)) AND productsCount > 3
ORDER BY checkedAt ASC
LIMIT ?`;
    const [categories] = await db.query(query, [limit]);

    return categories;

}

async function getCategoryByUrl(url) {
    const query = 'SELECT * FROM categories WHERE url = ?';
    const [category] = await db.query(query, [url]);
    return category;
}

async function getCategoryByNodeIdAndDepartmentId(nodeId, departmentId) {
    const query = 'SELECT * FROM categories WHERE nodeId = ? AND departmentId = ?';
    const [category] = await db.query(query, [nodeId, departmentId]);
    return category;
}

async function updateCategoryByNodeIdAndDepartmentId(nodeId, departmentId, category) {
    const query = 'UPDATE categories SET ? WHERE nodeId = ? AND departmentId = ?';
    await db.query(query, [category, nodeId, departmentId]);
    return getCategoryByNodeIdAndDepartmentId(nodeId, departmentId);
}
async function updateCategoryTryCheckedAt(categoryId) {
    const query = 'UPDATE categories SET tryCheckedAt = NOW() WHERE id = ?';
    db.query(query, [categoryId]);
}

async function updateCategoryCheckedAtByUrl(url) {
    const query = 'UPDATE categories SET checkedAt = NOW() WHERE url = ?';
    db.query(query, [url]);
}

async function createCategory(category) {
    const query = 'INSERT INTO categories (url, nodeId, departmentId, name, productsCount, pages) VALUES (?, ?, ?, ?, ?, ?)';
    const values = [category.url, category.nodeId, category.departmentId, category.name, category.productsCount, category.pages];
    const [result] = await db.query(query, values);
    return { id: result.insertId, ...category };
}

async function updateCategoryByUrl(url, category) {
    const query = 'UPDATE categories SET url = ?, nodeId = ?, departmentId = ?, name = ?, productsCount = ?, pages = ? WHERE url = ?';
    const values = [category.url, category.nodeId, category.departmentId, category.name, category.productsCount, category.pages, url];
    await db.query(query, values);
    return getCategoryByUrl(url);
}

module.exports = {
    getCategoriesToTryCheck,
    getCategoryByUrl,
    getCategoryByNodeIdAndDepartmentId,
    updateCategoryByUrl,
    updateCategoryByNodeIdAndDepartmentId,
    createCategory,
    updateCategoryTryCheckedAt,
    updateCategoryCheckedAtByUrl,
};